/* Command/reply header that precedes every chunk
 * sent between tyserver and client.
 */
struct tycommand {
    u_int8_t	cmd;		/* Cmd sent in, or echoed back */
    u_int8_t	err;		/* Error from server, or 0 */
    u_int16_t	streamid;	/* Stream-id of stream on the server */
    u_int32_t	offset;		/* Offset within stream: */
				/* Yes, should have bigger offset */
    u_int16_t	amount;		/* Amount of data: 0 <= amount <= 1499 */
};

/* Open: client sends above struct, followed by an ASCII string. The
 * amount field holds the string length, no bigger than 1499. Server
 * returns err=0 with stream-id, or some error.
 *
 * Save:  client sends above struct, followed by a buffer of data.
 * The amount holds the buffer size, and the offset is where to
 * put it into the streamid file. Server returns err=0 or some error.
 *
 * Play: client sends above struct + stream id + offset. Server returns
 * struct with err=0 and buffer, or error.
 */

#define TYCMD_LIST	1	/* Send back a list of streams */
#define TYCMD_OPEN	2	/* Open a file, get back a stream id */
#define TYCMD_SAVE	3	/* Client sends this, followed by a chunk */
#define TYCMD_PLAY	4	/* Client sends this, server sends it */
				/* back followed by a chunk */

#define TYERR_UNKCMD	1	/* Unknown command */
#define TYERR_OPEN	2	/* Can't open the named stream */
#define TYERR_READ	3	/* Can't read from the named stream */
#define TYERR_CREAT	4	/* Can't create the named stream */
#define TYERR_WRITE	5	/* Can't write to the named stream */
#define TYERR_BADOFF	6	/* Bad offset */
#define TYERR_BADAMT	7	/* Bad amount */
#define TYERR_BADID	8	/* bad stream id */
#define TYERR_LIST	9	/* Cannot give a listing */
